@@ -46,9 +46,17 @@ class Manage:
         })
 
         # Make the template context available in the template
-        @jinja2.contextfunction
-        def get_context(c):
-            return c
+        if hasattr(jinja2, 'pass_context'):
+
+            @jinja2.pass_context
+            def get_context(c):
+                return c
+
+        else:
+
+            @jinja2.contextfunction
+            def get_context(c):
+                return c
 
         self._app.jinja_env.globals['get_context'] = get_context
 
