@@ -122,7 +122,7 @@ def delete_document(state):
     # Check to see if the frame class supports `logged_delete`s and if so
     if hasattr(state.manage_config.frame_cls, 'logged_delete'):
         # Supports `logged_delete`
-        document.logged_delete(state.manage_user)
+        state.change_log_entry = document.logged_delete(state.manage_user)
 
     else:
         # Doesn't support `logged_delete`
