@@ -33,6 +33,8 @@ __all__ = [
     'get_document',
     'init_form',
     'mfa_authenticate',
+    'mfa_end_scoped_session',
+    'mfa_authenticate_scoped_session',
     'redirect',
     'render_template',
     'store_assets',
@@ -264,7 +266,10 @@ def mfa_authenticate_scoped_session(
 
     if get_cache is None:
         get_cache = lambda s: \
-                flask.current_app.config['USER_MFA_SCOPED_SESSION_CACHE']
+                flask.current_app.config[(
+                    f'{s.manage_config.frame_cls.get_settings_prefix()}'
+                    '_MFA_FAILED_AUTH_CACHE'
+                )]
 
     def mfa_authenticate_scoped_session(state):
 
@@ -331,11 +336,14 @@ def mfa_end_scoped_session(
 
     if get_cache is None:
         get_cache = lambda s: \
-                flask.current_app.config['USER_MFA_SCOPED_SESSION_CACHE']
+                flask.current_app.config[(
+                    f'{s.manage_config.frame_cls.get_settings_prefix()}'
+                    '_MFA_FAILED_AUTH_CACHE'
+                )]
 
     def mfa_end_scoped_session(state):
         secure.mfa.delete_scoped_session(
-            get_cache,
+            get_cache(state),
             flask.request.values.get('mfa_scoped_session_token')
         )
 
