@@ -157,7 +157,7 @@ def update_document(state):
     if hasattr(state.manage_config.frame_cls, 'logged_update'):
 
         # Supports `logged_update`
-        document.logged_update(
+        state.change_log_entry = document.logged_update(
             state.manage_user,
             form_data,
             *update_fields
